@@ -9,7 +9,6 @@ import botocore.exceptions
 import requests
 
 from nimbo import CONFIG
-from nimbo.core import telemetry
 from nimbo.core.cloud_provider.provider.services.instance import Instance
 from nimbo.core.cloud_provider.provider_impl.aws.services.aws_permissions import (
     AwsPermissions,
@@ -26,8 +25,6 @@ class AwsInstance(Instance):
             return {"message": job_cmd + "_dry_run"}
 
         # Launch instance with new volume for anaconda
-        telemetry.record_event("run")
-
         start_t = time.monotonic()
 
         instance_id = AwsInstance._start_instance()
@@ -251,28 +248,7 @@ class AwsInstance(Instance):
         if CONFIG.image[:4] == "ami-":
             image_id = CONFIG.image
         else:
-            response = requests.get(
-                "https://nimboami-default-rtdb.firebaseio.com/images.json"
-            )
-            catalog = response.json()
-            region = CONFIG.region_name
-            if region in catalog:
-                region_catalog = catalog[region]
-                image_name = CONFIG.image
-                if image_name in region_catalog:
-                    image_id = region_catalog[image_name]
-                else:
-                    raise ValueError(
-                        f"The image {image_name} was not found in the"
-                        " image catalog managed by Nimbo.\n"
-                        "Check https://docs.nimbo.sh/managed-images"
-                        " for the list of managed images."
-                    )
-            else:
-                raise ValueError(
-                    f"Currently, Nimbo does not support managed images in {region}."
-                    " Please use another region."
-                )
+            raise ValueError("You have to specify an AMI")
 
         return image_id
 
