@@ -14,7 +14,7 @@ def runner():
 
 @isolated_filesystem(RequiredCase.MINIMAL)
 def test_get_image_id(runner: CliRunner):
-    reference_image = "ubuntu18-latest-drivers"
+    reference_image = "ami-09a94552763ed1a2b"
     reference_region = "eu-west-1"
 
     CONFIG.image = reference_image
@@ -30,10 +30,6 @@ def test_get_image_id(runner: CliRunner):
     CONFIG.region_name = "us-east-2"
     AwsProvider._get_image_id()
 
-    with pytest.raises(ValueError):
-        CONFIG.region_name = "us-et-2"
-        AwsProvider._get_image_id()
-
     CONFIG.image = "ami-198571934781039"
     CONFIG.region_name = reference_region
     AwsProvider._get_image_id()
